@@ -22,8 +22,11 @@
 #	along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-VERSION=5.0.3.1
+VERSION=5.0.4
 
+PRODUCT=shorewall-core
+Product="Shorewall Core"
+ 
 usage() # $1 = exit status
 {
     ME=$(basename $0)
@@ -100,6 +103,9 @@ require()
     eval [ -n "\$$1" ] || fatal_error "Required option $1 not set"
 }
 
+#
+# Change to the directory containing this script
+#
 cd "$(dirname $0)"
 
 #
@@ -340,8 +346,10 @@ fi
 mkdir -p ${DESTDIR}${SBINDIR}
 chmod 755 ${DESTDIR}${SBINDIR}
 
-mkdir -p ${DESTDIR}${MANDIR}
-chmod 755 ${DESTDIR}${MANDIR}
+if [ -n "${MANDIR}" ]; then
+    mkdir -p ${DESTDIR}${MANDIR}
+    chmod 755 ${DESTDIR}${MANDIR}
+fi
 
 if [ -n "${INITFILE}" ]; then
     mkdir -p ${DESTDIR}${INITDIR}
